from fastapi import FastAPI, Depends

from .dependencies import verify_token
from .utils.email_code import smtp
from .routers.signin import router as signin_router
from .routers.signup import router as signup_router
from .routers.user_profile import router as user_profile_router
from .routers.user_account import router as user_account_router


app = FastAPI()
app.include_router(signup_router)
app.include_router(signin_router)
app.include_router(user_profile_router, dependencies=[Depends(verify_token)])
app.include_router(user_account_router, dependencies=[Depends(verify_token)])


@app.on_event('shutdown')
def close_smtp():
    smtp.close()


@app.get('/')
async def main():
    return {'code': 10000, 'msg': 'hello world'}

